datablock ParticleData(CLDevirtualizeParticle)
{
	textureName          = "base/data/shapes/white.png";
	dragCoefficient      = 0.3;
	gravityCoefficient   = -0.2;
	inheritedVelFactor   = 0.0;
	windCoefficient      = 0;
	constantAcceleration = 0.0;
	lifetimeMS           = 900;
	lifetimeVarianceMS   = 300;
	spinSpeed     = 0;
	spinRandomMin = -5.0;
	spinRandomMax =  5.0;
	useInvAlpha   = false;

	colors[0]	= "0.3 0.3 1.0 0.8";
	colors[1]	= "0.3 0.3 1.0 0.6";
	colors[2]	= "0.3 0.3 1.0 0";

	sizes[0]	= 0.2;
	sizes[1]	= 0.3;
	sizes[2]	= 0.1;

	times[0]	= 0.0;
	times[1]	= 0.8;
	times[2]	= 1.0;
};

datablock ParticleEmitterData(CLDevirtualizeEmitter)
{
	ejectionPeriodMS = 15;
	periodVarianceMS = 10.0;
	ejectionVelocity = 1.0;
	ejectionOffset   = 1.0;
	velocityVariance = 0.9;
	ejectionOffset	= 1.0;
	thetaMin		= 0;
	thetaMax		= 180;
	phiReferenceVel	= 0;
	phiVariance		= 360;
	overrideAdvance = false;
	particles = "CLDevirtualizeParticle";

	useEmitterColors = false;

	uiName = "CL Devirtualize";
};

datablock ShapeBaseImageData(CLDevirtualizeImage)
{
	shapeFile = "base/data/shapes/empty.dts";
	emap = true;

	mountPoint = 7;
	offset = "0 0 2.5";

	correctMuzzleVector = false;

	eyeOffset = "0.7 1.2 -0.25";

	className = "WeaponImage";

	item = CLSmokeItem;
	ammo = " ";

	melee = false;
	doRetraction = false;
	armReady = false;

	stateName[0]				= "Activate";
	stateTimeoutValue[0]		= 10.0;
	stateTransitionOnTimeout[0]	= "Done";
	stateEmitter[0]				= "CLDevirtualizeEmitter";
	stateEmitterTime[0]			= 10.0;
	stateEmitterNode[0]			= "mountPoint";

	stateName[1]	= "Done";
	stateScript[1]	= "onDone";
};

package CLDevirtualizeDeath
{
	function Armor::OnDisabled(%this, %obj, %enabled)
	{
		parent::OnDisabled(%this, %obj, %enabled);

		if(%obj.getDatablock().isWilliam)
		{
			%obj.CLDevirtualize();
			return;
		}

		if(%obj.lastDamageType != $DamageType::CLBlade && %obj.lastDamageType != $DamageType::CLBladeRanged)
			return;

		%obj.CLDevirtualize();
	}

	function player::damage(%this, %source, %pos, %directDamage, %damageType)
	{
		parent::damage(%this, %source, %pos, %directDamage, %damageType);
		%this.lastDamageType = %damageType;
	}

	function aiPlayer::damage(%this, %source, %pos, %directDamage, %damageType)
	{
		parent::damage(%this, %source, %pos, %directDamage, %damageType);
		%this.lastDamageType = %damageType;
	}
};
activatePackage(CLDevirtualizeDeath);

function Player::CLDevirtualize(%this)
{
	%this.unmountimage(0);
	%this.mountimage(CLDevirtualizeImage, 5);
	serverPlay3D(CLDevirtualizeSound, %this.getPosition());

	if(strStr(%this.getDatablock().shapeFile, "m.dts") == -1)
	{
		%this.CLFlashNode("ALL");
		%this.mountImage(CLDevirtualizeImage, 7);
		%this.schedule(700, unMountImage, 7);
		return;
	}

	%this.mountImage(CLDevirtualizeImage, 3);
	%this.hidenode(helmet);
	%this.hidenode(pointyHelmet);
	%this.hidenode(flareHelmet);
	%this.hidenode(scoutHat);
	%this.hidenode(bicorn);
	%this.hidenode(copHat);
	%this.hidenode(knitHat);
	%this.hidenode(plume);
	%this.hidenode(triplume);
	%this.hidenode(septplume);
	%this.hidenode(visor);
	%this.hidenode(femchest);
	%this.hidenode(LPeg);
	%this.hidenode(LHook);
	%this.hidenode(LArmSlim);
	%this.hidenode(skirtHip);
	%this.hidenode(RHook);
	%this.hidenode(RPeg);
	%this.hidenode(epaulets);
	%this.hidenode(epauletsRankA);
	%this.hidenode(epauletsRankB);
	%this.hidenode(epauletsRankC);
	%this.hidenode(epauletsRankD);
	%this.hidenode(ShoulderPads);
	%this.hidenode(armor);
	%this.hidenode(bucket);
	%this.hidenode(cape);
	%this.hidenode(pack);
	%this.hidenode(quiver);
	%this.hidenode(tank);
	%this.hidenode(RArmSlim);
	%this.hidenode(RSki);
	%this.hidenode(LSki);
	%this.schedule(0, CLFlashNode, "headSkin");
	%this.schedule(100, CLFlashNode, "chest");
	%this.schedule(200, CLFlashNode, "rarm");
	%this.schedule(200, CLFlashNode, "larm");
	%this.schedule(300, CLFlashNode, "rhand");
	%this.schedule(300, CLFlashNode, "lhand");
	%this.schedule(300, CLFlashNode, "pants");
	%this.schedule(400, CLFlashNode, "Lshoe");
	%this.schedule(400, CLFlashNode, "Rshoe");
	%this.schedule(700, unMountImage, 3);
}

function Player::CLFlashNode(%this, %node)
{
	if(%this.getDatablock().isWilliam)
		%color = "1 0 0";
	else
		%color = "0 1 1";

	%this.setNodeColor(%node, %color SPC "0.5");
	for(%i = 8; %i < 10; %i++)
	{
		%this.schedule(%i * 100, unhideNode, %node);
		%this.schedule(%i * 100 + 25, hideNode, %node);
	}
	%this.schedule(%i * 100, unhideNode, %node);
	%this.schedule(%i * 100, setNodeColor, %node, %color SPC "0.03");
}


function aiPlayer::CLDevirtualize(%this)
{
	%this.unmountimage(0);
	%this.mountimage(CLDevirtualizeImage, 5);
	serverPlay3D(CLDevirtualizeSound, %this.getPosition());

	if(strStr(%this.getDatablock().shapeFile, "m.dts") == -1)
	{
		%this.CLFlashNode("ALL");
		%this.mountImage(CLDevirtualizeImage, 7);
		%this.schedule(700, unMountImage, 7);
		return;
	}

	%this.mountImage(CLDevirtualizeImage, 3);
	%this.hidenode(helmet);
	%this.hidenode(pointyHelmet);
	%this.hidenode(flareHelmet);
	%this.hidenode(scoutHat);
	%this.hidenode(bicorn);
	%this.hidenode(copHat);
	%this.hidenode(knitHat);
	%this.hidenode(plume);
	%this.hidenode(triplume);
	%this.hidenode(septplume);
	%this.hidenode(visor);
	%this.hidenode(femchest);
	%this.hidenode(LPeg);
	%this.hidenode(LHook);
	%this.hidenode(LArmSlim);
	%this.hidenode(skirtHip);
	%this.hidenode(RHook);
	%this.hidenode(RPeg);
	%this.hidenode(epaulets);
	%this.hidenode(epauletsRankA);
	%this.hidenode(epauletsRankB);
	%this.hidenode(epauletsRankC);
	%this.hidenode(epauletsRankD);
	%this.hidenode(ShoulderPads);
	%this.hidenode(armor);
	%this.hidenode(bucket);
	%this.hidenode(cape);
	%this.hidenode(pack);
	%this.hidenode(quiver);
	%this.hidenode(tank);
	%this.hidenode(RArmSlim);
	%this.hidenode(RSki);
	%this.hidenode(LSki);
	%this.schedule(0, CLFlashNode, "headSkin");
	%this.schedule(100, CLFlashNode, "chest");
	%this.schedule(200, CLFlashNode, "rarm");
	%this.schedule(200, CLFlashNode, "larm");
	%this.schedule(300, CLFlashNode, "rhand");
	%this.schedule(300, CLFlashNode, "lhand");
	%this.schedule(300, CLFlashNode, "pants");
	%this.schedule(400, CLFlashNode, "Lshoe");
	%this.schedule(400, CLFlashNode, "Rshoe");
	%this.schedule(700, unMountImage, 3);
}

function aiPlayer::CLFlashNode(%this, %node)
{
	if(%this.getDatablock().isWilliam)
		%color = "1 0 0";
	else
		%color = "0 1 1";

	%this.setNodeColor(%node, %color SPC "0.5");
	for(%i = 8; %i < 10; %i++)
	{
		%this.schedule(%i * 100, unhideNode, %node);
		%this.schedule(%i * 100 + 25, hideNode, %node);
	}
	%this.schedule(%i * 100, unhideNode, %node);
	%this.schedule(%i * 100, setNodeColor, %node, %color SPC "0.03");
}
